<?php
/**
 * Themaga Customize Class
 *
 * @author   ThemeCountry
 * @since    1.0.0
 * @package  themaga
 *
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! function_exists( 'themaga_Customizer' ) ) {

	/**
	 * Themaga Customize Class
	 *
	 * @since 1.0.0
	 * @version 1.0
	 */
	class themaga_Customize {

		/**
		 * Class setup
		 *
		 * @since  1.0
		 * @access public
		 */
		public function __construct() {

			// Include Kirki Helper Class
			$this->includes();

			// Add Field
			add_action( 'init', array( $this, 'init_kirki' ) );
		}

		/**
		 * Includes files for Themaga Customizer
		 *
		 * @since 1.0
		 * @access private
		 * @return void
		 */
		private function includes() {

			require_once get_template_directory() . '/inc/helpers/class-include-kirki.php';
			require_once get_template_directory() . '/inc/helpers/class-helper-kirki.php';
			require_once get_template_directory() . '/inc/customizer/customize-settings.php';
			require_once get_template_directory() . '/inc/customizer/custom.php';
		}

		/**
		 * Initials Kirki customize
		 *
		 * @since 1.0
		 * @return void
		 */
		public function init_kirki() {

			themaga_Helper_Kirki::add_config( themaga_CUSTOMIZE_ID, array(
				'capability'    => 'edit_theme_options',
				'option_type'   => 'option',
				'option_name'	=> themaga_CUSTOMIZE_ID . '_name'
			) );


			themaga_Helper_Kirki::add_panel( 'themaga_panel' , array(
			    'priority'    => 100,
			    'title'       => __( 'Theme Options', 'themaga' ),
			    'description' => __( 'The basic theme options for free version.', 'themaga' ),
			) );

			// Add customize sections and fields
			$this->add_sections_settings();
		}

		/**
		 * Initils to add customize sections and settings.
		 *
		 * @since 1.0
		 * @return void
		 */
		private function add_sections_settings() {

			$sections = apply_filters ('themaga_customize_sections', $this->sections() );

			$fields = apply_filters ('themaga_customize_settings', $this->add_settings() );

			// Generate sections
			foreach( $sections as $key => $section ) {

				themaga_Helper_Kirki::add_section( $key, $section);

			}

			// Generate fields
			foreach ( $fields as $field) {

				themaga_Helper_Kirki::add_field( themaga_CUSTOMIZE_ID, $field );
			}

		}

		/**
		 * Adds theme cutomize section
		 *
		 * @since 1.0
		 * @return void
		 */
		private function sections() {

			return array(
				'themaga_general_section' => array(
				    'title'          => __( 'Genneral Settings', 'themaga' ),
				    'panel'          => 'themaga_panel',
				    'priority'       => 10,
				),
				'themaga_layout_section' => array(
				    'title'          => __( 'Layout Settings', 'themaga' ),
				    'panel'          => 'themaga_panel',
				    'priority'       => 20,
				),
				'themaga_single_post_section' => array(
				    'title'          => __( 'Single Post Settings', 'themaga' ),
				    'panel'          => 'themaga_panel',
				    'priority'       => 30,
				),
				'themaga_footer_widget_section' => array(
				    'title'          => __( 'Footer Widget Settings', 'themaga' ),
				    'panel'          => 'themaga_panel',
				    'priority'       => 40,
				)
			);
		}

		/**
		 * Adds theme customize settings
		 *
		 * @since 1.0
		 * @return array
		 */
		private function add_settings() {
			// Default layout fields
			$setttings = array_merge(
							themaga_customize_general_settings(),
							themaga_customize_layout_settings(),
							themaga_customize_single_post_settings(),
							themaga_customize_footer_widget_settings()
						);

			return $setttings;
		}

	}
}

return new themaga_Customize();
