<?php
/**
 * Custom cutomize section and settings.
 *
 */

function themaga_example_add_slide_section( $sections ) {

	$sections['themaga_homepage_section'] = array(
		    'title'          => __( 'Homepage Settings', 'themaga' ),
		    'panel'          => 'themaga_panel',
		    'priority'       => 1,
		);


	 return $sections;
}

add_filter( 'themaga_customize_sections', 'themaga_example_add_slide_section' );

function themaga_example_add_slide_settings ( $settings ) {

	$slide_settings  = array(

		//General section

		array(
				'settings'          => 'layout_post',
				'label'             => __('Site Layout', 'themaga'),
				'description'		=> __('This layout will apply hold website. But will not apply to custom homepage.', 'themaga'),
				'section'           => 'themaga_general_section',
				'type'              => 'radio-image',
				'default'           => 'right',
				'priority'          => 1,
				'choices'     		=> array(
					'left' 	=> get_template_directory_uri() . '/assets/images/customizer/controls/left.png',
					'right'  => get_template_directory_uri() . '/assets/images/customizer/controls/right.png',
					),

			),

		array(
			'settings'          => 'themaga_back_to_top',
			'label'             => __('Back To Top', 'themaga'),
			'section'           => 'themaga_general_section',
			'type'              => 'switch',
			'default'           => 1,
			'priority'          => 14,
			'choices'     		=> array(
				'on'				=> esc_attr__( 'On', 'themaga' ),
				'off'				=> esc_attr__( 'Off', 'themaga' ),
			),

		),

		// Featured section
		array(
			'settings'			=> 'enable_featured',
			'label'				=> __( 'Featured Settings', 'themaga' ),
			'section'			=> 'themaga_homepage_section',
			'type'				=> 'switch',
			'default'			=> 1,
			'priority'			=> 10,
		),

		array(
			'settings'		=> 'themaga_select_list',
			'type'        	=> 'select',
			'label'       	=> __( 'Select One Category', 'themaga' ),
			'section'		=> 'themaga_homepage_section',
			'default'    	=> '',
			'choices'		=> themaga_get_category_list(),
			'priority'			=> 10,
			'active_callback'	=> array(
					array(
						'setting'  => 'enable_featured',
						'operator' => '==',
						'value'    => 1,
					)
			)
		),

		// Homepage Post Style
		array(
			'settings'			=> 'enable_post_sections',
			'label'				=> __( 'Post Sections Settings', 'themaga' ),
			'section'			=> 'themaga_homepage_section',
			'type'				=> 'switch',
			'default'			=> 1,
			'priority'			=> 10,
		),

		array(
			'type'        => 'repeater',
			'label'       => esc_attr__( 'Post Section', 'themaga' ),
			'section'     => 'themaga_homepage_section',
			'priority'    => 10,
			'row_label' => array(
				'type' => 'text',
				'value' => esc_attr__('Homepage Section', 'themaga' ),
			),
			'button_label' => esc_attr__('Add Homepage Section', 'themaga' ),
			'settings'     => 'custom_homepage_control',
			'active_callback'	=> array(
					array(
						'setting'  => 'enable_post_sections',
						'operator' => '==',
						'value'    => 1,
					)
			),
			'default'      => array(			
				array(
					'link_text' => esc_attr__( 'Title Section', 'themaga' ),
					'link_url'  => '',
					'box_post' 	=> 'two_box',
					'number_post' => 6, 
				),
			),
			'fields' => array(
				'link_text' => array(
					'type'        => 'text',
					'label'       => esc_attr__( 'Title Post', 'themaga' ),
					'default'     => '',
				),
				'category_post' => array(
					'type'       		=> 'select',
					'label'				=> __( 'Select Category', 'themaga' ),
					'choices'			=> themaga_get_category_list(),
				),
				'box_post' => array(
					'type'       		=> 'select',
					'label'				=> __( 'Render Style', 'themaga' ),
					'choices'			=> array(
						'two_box'     			=> __( 'Two Boxes', 'themaga' ),
						'three_box'				=> __( 'Three Boxes', 'themaga' ),
						'list_box_sidebar' 		=> __( 'List Posts with Sidebar', 'themaga' ),
						'list_box_no_sidebar' 	=> __( 'List Posts No Sidebar', 'themaga' )
					),
				),
				'number_post' => array(
					'type'        		=> 'number',
					'label'				=> __( 'Number Of  Posts', 'themaga' ),
					'default'     		=> 6,
				),

				
			),			


		),
		
	);

	$settings = array_merge( $slide_settings, $settings);

	return apply_filters( 'themaga_example_add_slide_settings', $settings );

}

add_filter( 'themaga_customize_settings', 'themaga_example_add_slide_settings' );

function themaga_get_category_list() {
	
	$categories = get_categories();
	$cats[0] = __('All Categories', 'themaga');
	
	foreach ($categories as $cat) {
		$cats[$cat->cat_ID] = $cat->name;
	}

	return $cats;
}

add_filter( 'themaga_customize_general_settings', 'themaga_remove_some_controls' );

function themaga_remove_some_controls( $fields ) {

	$fields[] = array(

		'settings'		=> 'general_posts_modified_date',
		'type'			=> 'custom',

		);

	$fields[] = array(

		'settings'		=> 'single_post_metadata',
		'type'			=> 'custom',

		);

	$fields[] = array(

		'settings'		=> 'general_posts_date_prefix',
		'type'			=> 'custom',

		);

	return $fields;
}

add_filter( 'themaga_customize_single_post_settings', 'themaga_remove_single_some_controls' );

function themaga_remove_single_some_controls( $fields ) {

	$fields[] = array(

		'settings'		=> 'single_post_metadata',
		'type'			=> 'custom',

		);

	$fields[] = array(

		'settings'		=> 'single_post_modified_date',
		'type'			=> 'custom',

		);	

	return $fields;
}
add_filter( 'themaga_customize_layout_settings', 'themaga_remove_layout_some_controls' );

function themaga_remove_layout_some_controls( $fields ) {

	$fields[] = array(

		'settings'		=> 'layout_thumbnail_pos',
		'type'			=> 'custom',

		);

	$fields[] = array(

		'settings'		=> 'layout',
		'type'			=> 'custom',

	);

	$fields[] = array(

		'settings'		=> 'layout_show_thumbnail',
		'type'			=> 'custom',

	);
	

	return $fields;
}

